(ancestor tag)Return the first ancestor of tag.
Return the first ancestor of `tag`.
(ancestor? tag1 tag2)Return true if tag1 is an ancestor of tag2, otherwise return false.
Return `true` if `tag1` is an ancestor of `tag2`, otherwise return false.
(child tag)Return the first child of tag.
Return the first child of `tag`.
(child? tag1 tag2)Return true of tag1 is an child of tag2, otherwise return false.
Return `true` of `tag1` is an child of `tag2`, otherwise return false.
(children tag)(children tag h)Returns the immediate children of tag, either via a Java(Script) type
inheritance relationship or a relationship established via derive. h
must be a hierarchy obtained from make-hierarchy, if not supplied
defaults to the global hierarchy
Returns the immediate children of `tag`, either via a Java(Script) type inheritance relationship or a relationship established via derive. `h` must be a hierarchy obtained from make-hierarchy, if not supplied defaults to the global hierarchy
(descendant tag)Return the first descendant of tag.
Return the first descendant of `tag`.
(descendant? tag1 tag2)Return true if tag1 is an descendant of tag2, otherwise return false.
Return `true` if `tag1` is an descendant of `tag2`, otherwise return false.
(make-child tag)(make-child tag separator)Return a new unique keyword that derived from tag. This new keyword will
have the same name as tag with a number affixed. An optional separator
argument can be supplied, defaults to +
Return a new unique keyword that derived from `tag`. This new keyword will have the same name as `tag` with a number affixed. An optional `separator` argument can be supplied, defaults to `+`
(parent tag)Return the first parent of tag.
Return the first parent of `tag`.
(parent? tag1 tag2)Return true if tag1 is an parent of tag2, otherwise return false.
Return `true` if `tag1` is an parent of `tag2`, otherwise return false.
(underive-ancestors tag)Underive all tag of all its ancestors.
Underive all `tag` of all its ancestors.
(underive-children tag)Underive all children of tag.
Underive all children of `tag`.
(underive-descendants tag)Underive all descendants of tag.
Underive all descendants of `tag`.
(underive-parents tag)Underive all tag of all its parents.
Underive all `tag` of all its parents.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |